.. highlight:: shell

============
Installation
============


Stable release
--------------

To install flytrap, run this command in your terminal:

.. code-block:: console

    $ pip install flytrap

This is the preferred method to install flytrap, as it
will always install the most recent stable release.

To create the documentation, you can install flytrap
with the extra ``docs``:

.. code-block:: console

    $ pip install flytrap[docs]

To run the tests with pytest, you can install  flytrap
with the extra ``tests``:

.. code-block:: console

    $ pip install flytrap[tests]


If you don't have `pip <https://pip.pypa.io>`_ installed, this
`Python installation guide <https://docs.python-guide.org/starting/installation/>`_
can guide you through the process.

From sources
------------

The sources for flytrap can be downloaded from the
`Github repo <https://github.com/dodo325/flytrap>`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/dodo325/flytrap

Or download the `tarball <https://github.com/dodo325/flytrap/tarball/master>`_:

.. code-block:: console

    $ curl  -OL https://github.com/dodo325/flytrap/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install

